<?php

/**
 * @file
 * Contains \Drupal\ebt_core\Plugin\Field\FieldWidget\EbtSettingsDefaultWidget.
 */

namespace Drupal\ebt_core\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'ebt_settings_default' widget.
 *
 * @FieldWidget(
 *   id = "ebt_settings_default",
 *   label = @Translation("EBT example block settings"),
 *   field_types = {
 *     "ebt_settings"
 *   }
 * )
 */
class EbtSettingsDefaultWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element['option1'] = [
      '#title' => $this->t('Option1'),
      '#type' => 'textfield',
      '#default_value' => !empty($items[$delta]->ebt_settings['option1']) ? $items[$delta]->ebt_settings['option1'] : NULL,
    ];
    $element['option2'] = [
      '#title' => $this->t('Option2'),
      '#type' => 'radios',
      '#options' => [
        'jquery_ui' => 'jQuery UI',
        'flexslider' => 'FlexSlider',
      ],
      '#default_value' => isset($items[$delta]->ebt_settings['option2']) ? $items[$delta]->ebt_settings['option2'] : NULL,
    ];
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    foreach ($values as &$value) {
      $value += ['ebt_settings' => []];
    }
    return $values;
  }

}
